import { Accessor, Layer, LayerContext, LayerExtension } from '@deck.gl/core/typed';
export declare type CollideExtensionProps<DataT = any> = {
    /**
     * Accessor for collision priority. Must return a number in the range -1000 -> 1000. Features with higher values are shown preferentially.
     */
    getCollidePriority?: Accessor<DataT, number>;
    /**
     * Enable/disable collisions. If collisions are disabled, all objects are rendered.
     * @default true
     */
    collideEnabled: boolean;
    /**
     * Collision group this layer belongs to. If it is not set, the 'default' collision group is used
     */
    collideGroup?: string;
    /**
     * Props to override when rendering collision map
     */
    collideTestProps?: {};
};
/** Allows layers to hide overlapping objects. */
export default class CollideExtension extends LayerExtension {
    static defaultProps: {
        getCollidePriority: {
            type: string;
            value: number;
        };
        collideEnabled: boolean;
        collideGroup: {
            type: string;
            value: string;
        };
        collideTestProps: {};
    };
    static extensionName: string;
    isEnabled(layer: Layer<CollideExtensionProps>): boolean;
    getShaders(this: Layer<CollideExtensionProps>): any;
    draw(this: Layer<CollideExtensionProps>, { uniforms, context, moduleParameters }: any): void;
    initializeState(this: Layer<CollideExtensionProps>, context: LayerContext, extension: this): void;
    getNeedsPickingBuffer(this: Layer<CollideExtensionProps>): boolean;
}
//# sourceMappingURL=collide.d.ts.map